dateeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# dateeditor

class `camelot.view.controls.editors.dateeditor.` `DateEditor`(parent=None, editable=True, nullable=True, field_name='date', **kwargs)

  Widget for editing date values

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus